[Libreoffice-commits] core.git: 21 commits - chart2/source extensions/source filter/source hwpfilter/source i18nlangtag/source include/filter include/i18nlangtag include/vcl reportdesign/source sc/source sd/source sw/qa sw/source vcl/source writerfilter/source

Miklos Vajna vmiklos at collabora.co.uk
Thu Feb 6 07:13:42 PST 2014


 chart2/source/controller/chartapiwrapper/ChartDocumentWrapper.cxx |    2 
 chart2/source/controller/dialogs/ChartTypeDialogController.cxx    |    2 
 chart2/source/model/main/ChartModel_Persistence.cxx               |    2 
 extensions/source/bibliography/bibconfig.cxx                      |   13 -
 extensions/source/propctrlr/formcomponenthandler.cxx              |    3 
 filter/source/flash/swfexporter.cxx                               |   14 +
 filter/source/flash/swfexporter.hxx                               |    2 
 filter/source/flash/swfwriter2.cxx                                |   12 -
 filter/source/graphicfilter/icgm/bitmap.hxx                       |    5 
 filter/source/graphicfilter/icgm/bundles.hxx                      |   32 ++--
 hwpfilter/source/htags.cxx                                        |    8 -
 hwpfilter/source/htags.h                                          |    4 
 i18nlangtag/source/isolang/mslangid.cxx                           |    9 +
 include/filter/msfilter/svdfppt.hxx                               |   14 +
 include/i18nlangtag/mslangid.hxx                                  |    5 
 include/vcl/settings.hxx                                          |    3 
 reportdesign/source/core/sdr/RptObjectListener.cxx                |    5 
 sc/source/core/tool/platforminfo.cxx                              |    5 
 sc/source/ui/vba/vbanames.cxx                                     |    3 
 sc/source/ui/vba/vbanames.hxx                                     |    4 
 sd/source/ui/framework/configuration/ConfigurationController.cxx  |   10 -
 sd/source/ui/inc/framework/ConfigurationController.hxx            |    8 -
 sw/qa/extras/ww8export/data/comments-nested.doc                   |binary
 sw/qa/extras/ww8export/ww8export.cxx                              |    9 +
 sw/source/filter/ww8/wrtw8sty.cxx                                 |   48 ++++--
 sw/source/filter/ww8/wrtww8.cxx                                   |    2 
 sw/source/filter/ww8/wrtww8.hxx                                   |    6 
 sw/source/ui/uiview/pview.cxx                                     |   11 -
 vcl/source/app/settings.cxx                                       |   76 ++++++----
 writerfilter/source/dmapper/StyleSheetTable.cxx                   |    6 
 30 files changed, 204 insertions(+), 119 deletions(-)

New commits:
commit 8ae90efb8a0234fb4f95e8c59a173ee8fefef782
Author: Miklos Vajna <vmiklos at collabora.co.uk>
Date:   Thu Feb 6 16:04:56 2014 +0100

    DOC export: fix nested comments
    
    For one, replace m_nLastRangeStartPos with a map, so that we can keep
    track of the start positions when multiple comments are open at the same
    time.
    
    For another, sort PlcfAtnBkl and PlcfAtnBkf by position as Word requires
    it; with non-nested comments such explicit sorting wasn't necessary.
    This also required building two maps, so that we can know what
    PlcfAtnBkl index to reference in PlcfandRef, and what PlcfAtnBkf index
    to reference in PlcfAtnBkl after sorting.
    
    Change-Id: I2d7096b0c68a6b327efc4b5593ac96cdd297b3bd

diff --git a/sw/qa/extras/ww8export/data/comments-nested.doc b/sw/qa/extras/ww8export/data/comments-nested.doc
new file mode 100644
index 0000000..339a15b
Binary files /dev/null and b/sw/qa/extras/ww8export/data/comments-nested.doc differ
diff --git a/sw/qa/extras/ww8export/ww8export.cxx b/sw/qa/extras/ww8export/ww8export.cxx
index 1c4a8d7..4c3a0ba 100644
--- a/sw/qa/extras/ww8export/ww8export.cxx
+++ b/sw/qa/extras/ww8export/ww8export.cxx
@@ -188,6 +188,15 @@ DECLARE_WW8EXPORT_TEST(testFdo59530, "fdo59530.doc")
     CPPUNIT_ASSERT_EQUAL(OUString("AnnotationEnd"), getProperty<OUString>(xPropertySet, "TextPortionType"));
 }
 
+DECLARE_WW8EXPORT_TEST(testCommentsNested, "comments-nested.doc")
+{
+    uno::Reference<beans::XPropertySet> xOuter(getProperty< uno::Reference<beans::XPropertySet> >(getRun(getParagraph(1), 2), "TextField"), uno::UNO_QUERY);
+    CPPUNIT_ASSERT_EQUAL(OUString("Outer"), getProperty<OUString>(xOuter, "Content"));
+
+    uno::Reference<beans::XPropertySet> xInner(getProperty< uno::Reference<beans::XPropertySet> >(getRun(getParagraph(1), 4), "TextField"), uno::UNO_QUERY);
+    CPPUNIT_ASSERT_EQUAL(OUString("Inner"), getProperty<OUString>(xInner, "Content"));
+}
+
 #endif
 
 CPPUNIT_PLUGIN_IMPLEMENT();
diff --git a/sw/source/filter/ww8/wrtw8sty.cxx b/sw/source/filter/ww8/wrtw8sty.cxx
index 3f79db8..f631e65 100644
--- a/sw/source/filter/ww8/wrtw8sty.cxx
+++ b/sw/source/filter/ww8/wrtw8sty.cxx
@@ -2087,19 +2087,19 @@ WW8_Annotation::WW8_Annotation(const SwRedlineData* pRedline)
     maDateTime = pRedline->GetTimeStamp();
 }
 
-void WW8_WrPlcAnnotations::AddRangeStartPosition( WW8_CP nStartCp)
+void WW8_WrPlcAnnotations::AddRangeStartPosition(const OUString& rName, WW8_CP nStartCp)
 {
-    m_nLastRangeStartPos = nStartCp;
+    m_aRangeStartPositions[rName] = nStartCp;
 }
 
 void WW8_WrPlcAnnotations::Append( WW8_CP nCp, const SwPostItField *pPostIt )
 {
     aCps.push_back( nCp );
     WW8_Annotation* p;
-    if( m_nLastRangeStartPos != -1 )
+    if( m_aRangeStartPositions.find(pPostIt->GetName()) != m_aRangeStartPositions.end() )
     {
-        p = new WW8_Annotation(pPostIt, m_nLastRangeStartPos, nCp);
-        m_nLastRangeStartPos = -1;
+        p = new WW8_Annotation(pPostIt, m_aRangeStartPositions[pPostIt->GetName()], nCp);
+        m_aRangeStartPositions.erase(pPostIt->GetName());
     }
     else
     {
@@ -2269,6 +2269,11 @@ static bool lcl_AuthorComp( const std::pair<OUString,OUString>& aFirst, const st
     return aFirst.first < aSecond.first;
 }
 
+static bool lcl_PosComp( const std::pair<WW8_CP, int>& aFirst, const std::pair<WW8_CP, int>& aSecond)
+{
+    return aFirst.first < aSecond.first;
+}
+
 void WW8_WrPlcSubDoc::WriteGenericPlc( WW8Export& rWrt, sal_uInt8 nTTyp,
     WW8_FC& rTxtStart, sal_Int32& rTxtCount, WW8_FC& rRefStart, sal_Int32& rRefCount ) const
 {
@@ -2290,8 +2295,10 @@ void WW8_WrPlcSubDoc::WriteGenericPlc( WW8Export& rWrt, sal_uInt8 nTTyp,
     {
         case TXT_ATN:
             {
-                std::vector<WW8_CP> aRangeStartPos;
-                std::vector<WW8_CP> aRangeEndPos;
+                std::vector< std::pair<WW8_CP, int> > aRangeStartPos; // The second of the pair is the original index before sorting.
+                std::vector< std::pair<WW8_CP, int> > aRangeEndPos; // Same, so we can map between the indexes before/after sorting.
+                std::map<int, int> aAtnStartMap; // Maps from annotation index to start index.
+                std::map<int, int> aStartEndMap; // Maps from start index to end index.
                 // then write first the GrpXstAtnOwners
                 for ( i = 0; i < nLen; ++i )
                 {
@@ -2299,8 +2306,8 @@ void WW8_WrPlcSubDoc::WriteGenericPlc( WW8Export& rWrt, sal_uInt8 nTTyp,
                     aStrArr.push_back(std::pair<OUString,OUString>(rAtn.msOwner,rAtn.m_sInitials));
                     if( rAtn.m_nRangeStart != rAtn.m_nRangeEnd )
                     {
-                        aRangeStartPos.push_back(rAtn.m_nRangeStart);
-                        aRangeEndPos.push_back(rAtn.m_nRangeEnd);
+                        aRangeStartPos.push_back(std::make_pair(rAtn.m_nRangeStart, i));
+                        aRangeEndPos.push_back(std::make_pair(rAtn.m_nRangeEnd, i));
                     }
                 }
 
@@ -2309,6 +2316,17 @@ void WW8_WrPlcSubDoc::WriteGenericPlc( WW8Export& rWrt, sal_uInt8 nTTyp,
                 myiter aIter = ::std::unique(aStrArr.begin(), aStrArr.end());
                 aStrArr.erase(aIter, aStrArr.end());
 
+                // Also sort the start and end positions. We need to reference
+                // the start index in the annotation table and also need to
+                // reference the end index in the start table, so build a map
+                // that knows what index to reference, after sorting.
+                std::sort(aRangeStartPos.begin(), aRangeStartPos.end(), &lcl_PosComp);
+                for (i = 0; i < aRangeStartPos.size(); ++i)
+                    aAtnStartMap[aRangeStartPos[i].second] = i;
+                std::sort(aRangeEndPos.begin(), aRangeEndPos.end(), &lcl_PosComp);
+                for (i = 0; i < aRangeEndPos.size(); ++i)
+                    aStartEndMap[aRangeEndPos[ aAtnStartMap[i] ].second] = i;
+
                 if ( rWrt.bWrtWW8 )
                 {
                     for ( i = 0; i < aStrArr.size(); ++i )
@@ -2343,14 +2361,14 @@ void WW8_WrPlcSubDoc::WriteGenericPlc( WW8Export& rWrt, sal_uInt8 nTTyp,
                         rFib.fcPlcfAtnbkf = nFcStart;
                         for ( i = 0; i < aRangeStartPos.size(); ++i )
                         {
-                            SwWW8Writer::WriteLong( *rWrt.pTableStrm, aRangeStartPos[i] );
+                            SwWW8Writer::WriteLong( *rWrt.pTableStrm, aRangeStartPos[i].first );
                         }
-                        SwWW8Writer::WriteLong( *rWrt.pTableStrm, aRangeStartPos[i-1] + 1);
+                        SwWW8Writer::WriteLong( *rWrt.pTableStrm, aRangeStartPos[i-1].first + 1);
 
                         // Commented text ranges additional informations (Plcfbkf.aFBKF)
                         for ( i = 0; i < aRangeStartPos.size(); ++i )
                         {
-                            SwWW8Writer::WriteShort( *rWrt.pTableStrm, i ); // FBKF.ibkl
+                            SwWW8Writer::WriteShort( *rWrt.pTableStrm, aStartEndMap[i] ); // FBKF.ibkl
                             SwWW8Writer::WriteShort( *rWrt.pTableStrm, 0 ); // FBKF.bkc
                         }
 
@@ -2361,9 +2379,9 @@ void WW8_WrPlcSubDoc::WriteGenericPlc( WW8Export& rWrt, sal_uInt8 nTTyp,
                         rFib.fcPlcfAtnbkl = nFcStart;
                         for ( i = 0; i < aRangeEndPos.size(); ++i )
                         {
-                            SwWW8Writer::WriteLong( *rWrt.pTableStrm, aRangeEndPos[i] );
+                            SwWW8Writer::WriteLong( *rWrt.pTableStrm, aRangeEndPos[i].first );
                         }
-                        SwWW8Writer::WriteLong( *rWrt.pTableStrm, aRangeEndPos[i-1] + 1);
+                        SwWW8Writer::WriteLong( *rWrt.pTableStrm, aRangeEndPos[i-1].first + 1);
 
                         nFcStart = rWrt.pTableStrm->Tell();
                         rFib.lcbPlcfAtnbkl = nFcStart - rFib.fcPlcfAtnbkl;
@@ -2379,7 +2397,7 @@ void WW8_WrPlcSubDoc::WriteGenericPlc( WW8Export& rWrt, sal_uInt8 nTTyp,
                             SwWW8Writer::WriteShort( *rWrt.pTableStrm, 0 );         // SttbfAtnBkmk.cchData
                             // One ATNBE structure for all text ranges
                             SwWW8Writer::WriteShort( *rWrt.pTableStrm, 0x0100 );    // ATNBE.bmc
-                            SwWW8Writer::WriteLong( *rWrt.pTableStrm, i );          // ATNBE.lTag
+                            SwWW8Writer::WriteLong( *rWrt.pTableStrm, aAtnStartMap[i] );          // ATNBE.lTag
                             SwWW8Writer::WriteLong( *rWrt.pTableStrm, -1 );         // ATNBE.lTagOld
                         }
 
diff --git a/sw/source/filter/ww8/wrtww8.cxx b/sw/source/filter/ww8/wrtww8.cxx
index 6c82898..43a1cfa 100644
--- a/sw/source/filter/ww8/wrtww8.cxx
+++ b/sw/source/filter/ww8/wrtww8.cxx
@@ -1388,7 +1388,7 @@ void WW8Export::AppendAnnotationMarks(const SwTxtNode& rNode, sal_Int32 nAktPos,
             const sal_Int32 nStart = pMark->GetMarkStart().nContent.GetIndex();
             if (nStart == nAktPos)
             {
-                pAtn->AddRangeStartPosition(Fc2Cp(Strm().Tell()));
+                pAtn->AddRangeStartPosition(pMark->GetName(), Fc2Cp(Strm().Tell()));
                 return;
             }
         }
diff --git a/sw/source/filter/ww8/wrtww8.hxx b/sw/source/filter/ww8/wrtww8.hxx
index 1a781e5..30ee97d 100644
--- a/sw/source/filter/ww8/wrtww8.hxx
+++ b/sw/source/filter/ww8/wrtww8.hxx
@@ -1226,12 +1226,12 @@ private:
     WW8_WrPlcAnnotations& operator=(WW8_WrPlcAnnotations&);
     std::set<const SwRedlineData*> maProcessedRedlines;
 
-    WW8_CP  m_nLastRangeStartPos;
+    std::map<const OUString, WW8_CP> m_aRangeStartPositions;
 public:
-    WW8_WrPlcAnnotations(): m_nLastRangeStartPos(-1){}
+    WW8_WrPlcAnnotations() {}
     ~WW8_WrPlcAnnotations();
 
-    void AddRangeStartPosition( WW8_CP nStartCp );
+    void AddRangeStartPosition(const OUString& rName, WW8_CP nStartCp);
     void Append( WW8_CP nCp, const SwPostItField* pPostIt );
     void Append( WW8_CP nCp, const SwRedlineData* pRedLine );
     bool IsNewRedlineComment( const SwRedlineData* pRedLine );
commit b37bce11cf59c6c9544e62e81f71a07e4d987a34
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Thu Feb 6 13:00:50 2014 +0000

    Resolves: rhbz#975421 wrong chart direction in Farsi
    
    Where Farsi (and apparenly Moroccon) are RTL but have LTR
    math and charts should reportedly follow the math direction
    
    Change-Id: Ib60eaaaa90fe46ef240030a91169fdff3f736329

diff --git a/chart2/source/controller/chartapiwrapper/ChartDocumentWrapper.cxx b/chart2/source/controller/chartapiwrapper/ChartDocumentWrapper.cxx
index e1e38cd..342facf 100644
--- a/chart2/source/controller/chartapiwrapper/ChartDocumentWrapper.cxx
+++ b/chart2/source/controller/chartapiwrapper/ChartDocumentWrapper.cxx
@@ -1303,7 +1303,7 @@ uno::Reference< uno::XInterface > SAL_CALL ChartDocumentWrapper::createInstance(
                     if( aTemplateWithService.first.is())
                         aTemplateWithService.first->resetStyles( xDiagram );//#i109371#
                     xTemplate->changeDiagram( xDiagram );
-                    if( Application::GetSettings().GetLayoutRTL() )
+                    if( Application::GetSettings().GetMathLayoutRTL() )
                         AxisHelper::setRTLAxisLayout( AxisHelper::getCoordinateSystemByIndex( xDiagram, 0 ) );
                     ThreeDHelper::setScheme( xDiagram, e3DScheme );
                 }
diff --git a/chart2/source/controller/dialogs/ChartTypeDialogController.cxx b/chart2/source/controller/dialogs/ChartTypeDialogController.cxx
index 3aee103..5cdda02 100644
--- a/chart2/source/controller/dialogs/ChartTypeDialogController.cxx
+++ b/chart2/source/controller/dialogs/ChartTypeDialogController.cxx
@@ -329,7 +329,7 @@ bool ChartTypeDialogController::commitToModel( const ChartTypeParameter& rParame
         if( aTemplateWithService.first.is())
             aTemplateWithService.first->resetStyles( xDiagram );
         xTemplate->changeDiagram( xDiagram );
-        if( Application::GetSettings().GetLayoutRTL() )
+        if( Application::GetSettings().GetMathLayoutRTL() )
             AxisHelper::setRTLAxisLayout( AxisHelper::getCoordinateSystemByIndex( xDiagram, 0 ) );
         if( rParameter.b3DLook )
             ThreeDHelper::setScheme( xDiagram, rParameter.eThreeDLookScheme );
diff --git a/chart2/source/model/main/ChartModel_Persistence.cxx b/chart2/source/model/main/ChartModel_Persistence.cxx
index d964ced..003e335 100644
--- a/chart2/source/model/main/ChartModel_Persistence.cxx
+++ b/chart2/source/model/main/ChartModel_Persistence.cxx
@@ -412,7 +412,7 @@ void SAL_CALL ChartModel::initNew()
 
                 setFirstDiagram( xDiagram );
 
-                bool bIsRTL = Application::GetSettings().GetLayoutRTL();
+                bool bIsRTL = Application::GetSettings().GetMathLayoutRTL();
                 //reverse x axis for rtl charts
                 if( bIsRTL )
                     AxisHelper::setRTLAxisLayout( AxisHelper::getCoordinateSystemByIndex( xDiagram, 0 ) );
diff --git a/i18nlangtag/source/isolang/mslangid.cxx b/i18nlangtag/source/isolang/mslangid.cxx
index e27e13b..6bb92bb 100644
--- a/i18nlangtag/source/isolang/mslangid.cxx
+++ b/i18nlangtag/source/isolang/mslangid.cxx
@@ -233,6 +233,15 @@ bool MsLangId::isRightToLeft( LanguageType nLang )
 }
 
 // static
+bool MsLangId::isRightToLeftMath( LanguageType nLang )
+{
+    //http://www.w3.org/TR/arabic-math/
+    if (nLang == LANGUAGE_FARSI || nLang == LANGUAGE_ARABIC_MOROCCO)
+        return false;
+    return isRightToLeft(nLang);
+}
+
+// static
 bool MsLangId::isSimplifiedChinese( LanguageType nLang )
 {
     return isChinese(nLang) && !isTraditionalChinese(nLang);
diff --git a/include/i18nlangtag/mslangid.hxx b/include/i18nlangtag/mslangid.hxx
index a30bb1d2..b12c34c 100644
--- a/include/i18nlangtag/mslangid.hxx
+++ b/include/i18nlangtag/mslangid.hxx
@@ -107,9 +107,12 @@ public:
     static LanguageType resolveSystemLanguageByScriptType( LanguageType nLang, sal_Int16 nType );
 
 
-    /** Whether locale has a Right-To-Left orientation. */
+    /** Whether locale has a Right-To-Left orientation for text. */
     static bool isRightToLeft( LanguageType nLang );
 
+    /** Whether locale has a Right-To-Left orientation for math. */
+    static bool isRightToLeftMath( LanguageType nLang );
+
     /** Whether locale is a CJK locale */
     static bool isCJK( LanguageType nLang );
 
diff --git a/vcl/source/app/settings.cxx b/vcl/source/app/settings.cxx
index fe1456b..541f881 100644
--- a/vcl/source/app/settings.cxx
+++ b/vcl/source/app/settings.cxx
@@ -1591,47 +1591,63 @@ void AllSettings::SetUILanguageTag( const LanguageTag& )
 
 // -----------------------------------------------------------------------
 
-bool AllSettings::GetLayoutRTL() const
+namespace
 {
-    static const char* pEnv = getenv("SAL_RTL_ENABLED" );
-    static int  nUIMirroring = -1;   // -1: undef, 0: auto, 1: on 2: off
+    bool GetConfigLayoutRTL(bool bMath)
+    {
+        static const char* pEnv = getenv("SAL_RTL_ENABLED" );
+        static int  nUIMirroring = -1;   // -1: undef, 0: auto, 1: on 2: off
 
-    // environment always overrides
-    if( pEnv )
-        return true;
+        // environment always overrides
+        if( pEnv )
+            return true;
 
-    bool bRTL = false;
+        bool bRTL = false;
 
-    if( nUIMirroring == -1 )
-    {
-        nUIMirroring = 0; // ask configuration only once
-        utl::OConfigurationNode aNode = utl::OConfigurationTreeRoot::tryCreateWithComponentContext(
-            comphelper::getProcessComponentContext(),
-            OUString("org.openoffice.Office.Common/I18N/CTL") );    // note: case sensitive !
-        if ( aNode.isValid() )
+        if( nUIMirroring == -1 )
         {
-            sal_Bool bTmp = sal_Bool();
-            ::com::sun::star::uno::Any aValue = aNode.getNodeValue( OUString("UIMirroring") );
-            if( aValue >>= bTmp )
+            nUIMirroring = 0; // ask configuration only once
+            utl::OConfigurationNode aNode = utl::OConfigurationTreeRoot::tryCreateWithComponentContext(
+                comphelper::getProcessComponentContext(),
+                OUString("org.openoffice.Office.Common/I18N/CTL") );    // note: case sensitive !
+            if ( aNode.isValid() )
             {
-                // found true or false; if it was nil, nothing is changed
-                nUIMirroring = bTmp ? 1 : 2;
+                sal_Bool bTmp = sal_Bool();
+                ::com::sun::star::uno::Any aValue = aNode.getNodeValue( OUString("UIMirroring") );
+                if( aValue >>= bTmp )
+                {
+                    // found true or false; if it was nil, nothing is changed
+                    nUIMirroring = bTmp ? 1 : 2;
+                }
             }
         }
-    }
 
-    if( nUIMirroring == 0 )  // no config found (eg, setup) or default (nil) was set: check language
-    {
-        LanguageType aLang = LANGUAGE_DONTKNOW;
-        ImplSVData* pSVData = ImplGetSVData();
-        if ( pSVData->maAppData.mpSettings )
-            aLang = pSVData->maAppData.mpSettings->GetUILanguageTag().getLanguageType();
-        bRTL = MsLangId::isRightToLeft( aLang );
+        if( nUIMirroring == 0 )  // no config found (eg, setup) or default (nil) was set: check language
+        {
+            LanguageType aLang = LANGUAGE_DONTKNOW;
+            ImplSVData* pSVData = ImplGetSVData();
+            if ( pSVData->maAppData.mpSettings )
+                aLang = pSVData->maAppData.mpSettings->GetUILanguageTag().getLanguageType();
+            if (bMath)
+                bRTL = MsLangId::isRightToLeftMath( aLang );
+            else
+                bRTL = MsLangId::isRightToLeft( aLang );
+        }
+        else
+            bRTL = (nUIMirroring == 1);
+
+        return bRTL;
     }
-    else
-        bRTL = (nUIMirroring == 1);
+}
 
-    return bRTL;
+bool AllSettings::GetLayoutRTL() const
+{
+    return GetConfigLayoutRTL(false);
+}
+
+bool AllSettings::GetMathLayoutRTL() const
+{
+    return GetConfigLayoutRTL(true);
 }
 
 // -----------------------------------------------------------------------
commit eb07ab05c3b8774ab2b2059befef0eadf61c97d6
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Thu Feb 6 13:25:44 2014 +0000

    coverity#707771 coverity gold, Uninitialized m_refCount
    
    Change-Id: I98398a3cd7a86a5f31c711f7f1cff0d467a1d2e5

diff --git a/extensions/source/propctrlr/formcomponenthandler.cxx b/extensions/source/propctrlr/formcomponenthandler.cxx
index c6d5f31..e42efd8 100644
--- a/extensions/source/propctrlr/formcomponenthandler.cxx
+++ b/extensions/source/propctrlr/formcomponenthandler.cxx
@@ -2986,7 +2986,8 @@ namespace pcr
         {
         protected:
             SQLCommandPropertyUI( const Reference< XPropertySet >& _rxObject )
-                :m_xObject( _rxObject )
+                : m_xObject(_rxObject)
+                , m_refCount(0)
             {
                 if ( !m_xObject.is() )
                     throw NullPointerException();
commit b178dd287063c1ff661c087174749b2dde59ad04
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Thu Feb 6 14:52:24 2014 +0000

    coverity#1130195 Unchecked dynamic_cast
    
    Change-Id: I2631bd208f8a66798ae7bd1daaf0cec679f2810c

diff --git a/writerfilter/source/dmapper/StyleSheetTable.cxx b/writerfilter/source/dmapper/StyleSheetTable.cxx
index be6fbc0..47cba7b 100644
--- a/writerfilter/source/dmapper/StyleSheetTable.cxx
+++ b/writerfilter/source/dmapper/StyleSheetTable.cxx
@@ -644,12 +644,14 @@ void StyleSheetTable::lcl_sprm(Sprm & rSprm)
 
                 if (nSprmId == NS_ooxml::LN_CT_Style_tblPr)
                 {
-                    pTableEntry->AppendInteropGrabBag(pTblStylePrHandler->getInteropGrabBag("tblPr"));
+                    if (pTableEntry != NULL)
+                        pTableEntry->AppendInteropGrabBag(pTblStylePrHandler->getInteropGrabBag("tblPr"));
                 }
                 else if (nSprmId == NS_ooxml::LN_CT_Style_tblStylePr)
                 {
                     pTblStylePrHandler->appendInteropGrabBag("type", pTblStylePrHandler->getTypeString());
-                    pTableEntry->AppendInteropGrabBag(pTblStylePrHandler->getInteropGrabBag("tblStylePr"));
+                    if (pTableEntry != NULL)
+                        pTableEntry->AppendInteropGrabBag(pTblStylePrHandler->getInteropGrabBag("tblStylePr"));
                 }
             }
             break;
commit 5d4b38c4a284d610583a283a6f405d962673ff8f
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Thu Feb 6 14:48:27 2014 +0000

    coverity#707901 Uninitialized scalar field
    
    Change-Id: Ib8d046e279e76a94cf2198ba35bb70d074a3e350

diff --git a/hwpfilter/source/htags.cxx b/hwpfilter/source/htags.cxx
index 938df44..6283e77 100644
--- a/hwpfilter/source/htags.cxx
+++ b/hwpfilter/source/htags.cxx
@@ -78,18 +78,18 @@ bool EmPicture::Read(HWPFile & hwpf)
 
 
 OlePicture::OlePicture(int tsize)
+    : signature(0)
+    , pis(NULL)
 {
     size = tsize - 4;
     if (size <= 0)
         return;
-#ifdef WIN32
-     pis = 0L;
-#else
+#ifndef WIN32
      pis = new char[size];
 #endif
 };
 
-OlePicture::~OlePicture(void)
+OlePicture::~OlePicture()
 {
 #ifdef WIN32
      if( pis )
diff --git a/hwpfilter/source/htags.h b/hwpfilter/source/htags.h
index 591b2e1..3b7006b 100644
--- a/hwpfilter/source/htags.h
+++ b/hwpfilter/source/htags.h
@@ -56,9 +56,9 @@ struct OlePicture
     int   size;
     ulong signature;
 #ifdef WIN32
-     IStorage *pis;
+    IStorage *pis;
 #else
-     char *pis;
+    char *pis;
 #endif
     OlePicture(int tsize);
     ~OlePicture(void);
commit b4075c9efd229e1ec7b38e821a63e7989ae46c52
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Thu Feb 6 14:21:05 2014 +0000

    coverity#707968 Uninitialized pointer field
    
    Change-Id: I85da713ec4f0e1e0180e9f7833a52a2768142a66

diff --git a/reportdesign/source/core/sdr/RptObjectListener.cxx b/reportdesign/source/core/sdr/RptObjectListener.cxx
index 31a4815..80752ef 100644
--- a/reportdesign/source/core/sdr/RptObjectListener.cxx
+++ b/reportdesign/source/core/sdr/RptObjectListener.cxx
@@ -63,8 +63,9 @@ TYPEINIT1( DlgEdHint, SfxHint );
 
 //----------------------------------------------------------------------------
 
-DlgEdHint::DlgEdHint( DlgEdHintKind eHint )
-    :eHintKind( eHint )
+DlgEdHint::DlgEdHint(DlgEdHintKind eHint)
+    : eHintKind(eHint)
+    , pDlgEdObj(NULL)
 {
 }
 
commit 52235d4a74af7f37b9587a7bcae8acaa82814a63
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Thu Feb 6 14:19:23 2014 +0000

    coverity#707787 Uninitialized scalar field
    
    Change-Id: Id23ef57395f63a7a3f5df64bd470f8053ceed35e

diff --git a/filter/source/flash/swfexporter.cxx b/filter/source/flash/swfexporter.cxx
index 5382f84..1c9b715 100644
--- a/filter/source/flash/swfexporter.cxx
+++ b/filter/source/flash/swfexporter.cxx
@@ -92,12 +92,14 @@ void PageInfo::addShape( ShapeInfo* pShapeInfo )
 // -----------------------------------------------------------------------------
 
 FlashExporter::FlashExporter(const Reference< XComponentContext > &rxContext, sal_Int32 nJPEGCompressMode, sal_Bool bExportOLEAsJPEG)
-:   mxContext( rxContext ),
-    mpWriter( NULL ),
-    mnJPEGcompressMode(nJPEGCompressMode),
-    mbExportOLEAsJPEG(bExportOLEAsJPEG),
-    mbPresentation(true),
-    mnPageNumber( - 1 )
+    : mxContext(rxContext)
+    , mpWriter(NULL)
+    , mnDocWidth(0)
+    , mnDocHeight(0)
+    , mnJPEGcompressMode(nJPEGCompressMode)
+    , mbExportOLEAsJPEG(bExportOLEAsJPEG)
+    , mbPresentation(true)
+    , mnPageNumber(-1)
 {
 }
 
commit a9102eba62f88bc749339cd23a0dba0d4bd9bd7a
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Thu Feb 6 14:17:32 2014 +0000

    coverity#707781 Uninitialized scalar field
    
    Change-Id: Ic29735bc125b2b9e662e97402dfccf72f7dedb5d

diff --git a/include/filter/msfilter/svdfppt.hxx b/include/filter/msfilter/svdfppt.hxx
index f76123a..286c1a0 100644
--- a/include/filter/msfilter/svdfppt.hxx
+++ b/include/filter/msfilter/svdfppt.hxx
@@ -366,12 +366,14 @@ struct PPTOleEntry
     sal_uInt16          nType;                      // maybe PPT_PST_ExEmbed or PPT_PST_ExControl
     sal_uInt32          nAspect;                    // the aspect of the OLE object
 
-    PPTOleEntry( sal_uInt32 nid, sal_uInt32 nOfs, SfxObjectShell* pSh, sal_uInt16 nT, sal_uInt32 nAsp ) :
-        nId             ( nid ),
-        nRecHdOfs       ( nOfs ),
-        pShell          ( pSh ),
-        nType           ( nT ),
-        nAspect         ( nAsp ) {}
+    PPTOleEntry( sal_uInt32 nid, sal_uInt32 nOfs, SfxObjectShell* pSh, sal_uInt16 nT, sal_uInt32 nAsp )
+        : nId(nid)
+        , nPersistPtr(0)
+        , nRecHdOfs(nOfs)
+        , pShell(pSh)
+        , nType(nT)
+        , nAspect(nAsp)
+    {}
 };
 
 struct PptExOleObjAtom
commit 92d0dabd505d0c44aa275469119e3fb6d7c62717
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Thu Feb 6 13:23:38 2014 +0000

    coverity#707770 Uninitialized scalar field
    
    Change-Id: Ie324197ac0069d8c534cee7a2bae524f9d7f2207

diff --git a/extensions/source/bibliography/bibconfig.cxx b/extensions/source/bibliography/bibconfig.cxx
index efb1972..64ada45 100644
--- a/extensions/source/bibliography/bibconfig.cxx
+++ b/extensions/source/bibliography/bibconfig.cxx
@@ -55,12 +55,13 @@ Sequence<OUString> BibConfig::GetPropertyNames()
     return aNames;
 }
 
-BibConfig::BibConfig() :
-    ConfigItem("Office.DataAccess/Bibliography", CONFIG_MODE_DELAYED_UPDATE),
-    pMappingsArr(new MappingArray),
-    nBeamerSize(0),
-    nViewSize(0),
-    bShowColumnAssignmentWarning(sal_False)
+BibConfig::BibConfig()
+    : ConfigItem("Office.DataAccess/Bibliography", CONFIG_MODE_DELAYED_UPDATE)
+    , nTblOrQuery(0)
+    , pMappingsArr(new MappingArray)
+    , nBeamerSize(0)
+    , nViewSize(0)
+    , bShowColumnAssignmentWarning(false)
 {
     //Names of the default columns
     aColumnDefaults[0] = "Identifier";
commit 37126a47290608f9af7debb69f35d26ac13fd265
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Thu Feb 6 13:20:57 2014 +0000

    coverity#1130477 Uninitialized pointer field
    
    Change-Id: I9f79064a90fda56194c70f545219310db7e4aed5

diff --git a/sw/source/ui/uiview/pview.cxx b/sw/source/ui/uiview/pview.cxx
index b969162..fc8ee68 100644
--- a/sw/source/ui/uiview/pview.cxx
+++ b/sw/source/ui/uiview/pview.cxx
@@ -166,11 +166,12 @@ void  SwPreviewZoomDlg::Apply()
 
 // all for SwPagePreviewWin
 SwPagePreviewWin::SwPagePreviewWin( Window *pParent, SwPagePreview& rPView )
-    : Window( pParent, WinBits( WB_CLIPCHILDREN) ),
-    mpViewShell( 0 ),
-    mrView( rPView ),
-    mbCalcScaleForPreviewLayout( true ),
-    maPaintedPreviewDocRect( Rectangle(0,0,0,0) )
+    : Window(pParent, WinBits(WB_CLIPCHILDREN))
+    , mpViewShell(0)
+    , mrView(rPView)
+    , mbCalcScaleForPreviewLayout(true)
+    , maPaintedPreviewDocRect(Rectangle(0,0,0,0))
+    , mpPgPreviewLayout(NULL)
 {
     SetOutDevViewType( OUTDEV_VIEWTYPE_PRINTPREVIEW );
     SetHelpId(HID_PAGEPREVIEW);
commit b2801e50851c2ad5aba1961387b03abad4a1ce7a
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Thu Feb 6 13:16:12 2014 +0000

    coverity#1103770 Uninitialized pointer field
    
    Change-Id: I4ea37577f66db3b6ef41ad3a9b2b9e7904463dac

diff --git a/sc/source/core/tool/platforminfo.cxx b/sc/source/core/tool/platforminfo.cxx
index 74f5136..1679668 100644
--- a/sc/source/core/tool/platforminfo.cxx
+++ b/sc/source/core/tool/platforminfo.cxx
@@ -14,7 +14,10 @@ namespace sc {
 
 OpenclDeviceInfo::OpenclDeviceInfo() {}
 
-OpenclPlatformInfo::OpenclPlatformInfo() {}
+OpenclPlatformInfo::OpenclPlatformInfo()
+    : platform(NULL)
+{
+}
 
 }
 
commit db9f44dee33236f52b35f8f57df2273089e2b3b0
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Thu Feb 6 13:13:41 2014 +0000

    coverity#707789 Uninitialized scalar field
    
    Change-Id: I4eb999220ca4e0134c15214504bd7c6e6e143479

diff --git a/filter/source/flash/swfexporter.hxx b/filter/source/flash/swfexporter.hxx
index 3c9cb79..67e5c1d 100644
--- a/filter/source/flash/swfexporter.hxx
+++ b/filter/source/flash/swfexporter.hxx
@@ -85,7 +85,7 @@ public:
     sal_Int32       mnBlueScreenColor;
 
     ShapeInfo() :
-        mnID(0), mnX(0), mnY(0),
+        mnID(0), mnX(0), mnY(0), mnWidth(0), mnHeight(0),
         meEffect( ::com::sun::star::presentation::AnimationEffect_NONE ),
         meTextEffect( ::com::sun::star::presentation::AnimationEffect_NONE ),
         meEffectSpeed( ::com::sun::star::presentation::AnimationSpeed_MEDIUM ),
commit 48ca6aeda3d0122dc085de5801847afbb07039d5
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Thu Feb 6 13:12:25 2014 +0000

    coverity#707791 Uninitialized scalar field
    
    Change-Id: I85cbe3d93559e65291c8ff0949bb80d6f595e4b9

diff --git a/filter/source/flash/swfwriter2.cxx b/filter/source/flash/swfwriter2.cxx
index 846eb19..8bbc476 100644
--- a/filter/source/flash/swfwriter2.cxx
+++ b/filter/source/flash/swfwriter2.cxx
@@ -519,8 +519,9 @@ void FlashFont::write( SvStream& out )
 
 /** this c'tor creates a solid fill style */
 FillStyle::FillStyle( const Color& rSolidColor )
-:   meType( solid ),
-    maColor( rSolidColor )
+    : meType(solid )
+    , mnBitmapId(0)
+    , maColor(rSolidColor)
 {
 }
 
commit 53073c951fee862d612e5b61c5ae6366e1b464a1
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Thu Feb 6 13:11:27 2014 +0000

    coverity#707792 Uninitialized scalar field
    
    Change-Id: Ifcf2e899b7686f183b52b95f6f4ad334c17295b0

diff --git a/filter/source/flash/swfwriter2.cxx b/filter/source/flash/swfwriter2.cxx
index 9c9599f..846eb19 100644
--- a/filter/source/flash/swfwriter2.cxx
+++ b/filter/source/flash/swfwriter2.cxx
@@ -556,9 +556,10 @@ FillStyle::FillStyleType Impl_getFillStyleType( const Gradient& rGradient )
 
 /** this c'tor creates a linear or radial gradient fill style */
 FillStyle::FillStyle( const Rectangle& rBoundRect, const Gradient& rGradient )
-:   meType( Impl_getFillStyleType( rGradient ) ),
-    maGradient( rGradient ),
-    maBoundRect( rBoundRect )
+    : meType(Impl_getFillStyleType(rGradient))
+    , mnBitmapId(0)
+    , maGradient(rGradient)
+    , maBoundRect(rBoundRect)
 {
 }
 
commit fd3473d225c2c15b2bb50cf81dca77092bdf3034
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Thu Feb 6 13:08:34 2014 +0000

    coverity#707803 Uninitialized scalar field
    
    Change-Id: Icd57bd3cd80f85e17d306bed4e541ce5827d92c0

diff --git a/filter/source/graphicfilter/icgm/bitmap.hxx b/filter/source/graphicfilter/icgm/bitmap.hxx
index 3a5e3f8..7017984 100644
--- a/filter/source/graphicfilter/icgm/bitmap.hxx
+++ b/filter/source/graphicfilter/icgm/bitmap.hxx
@@ -53,10 +53,15 @@ class CGMBitmapDescriptor
             , mbStatus(sal_False)
             , mbVMirror(sal_False)
             , mbHMirror(sal_False)
+            , mnDstBitsPerPixel(0)
+            , mnScanSize(0)
             , mndx(0.0)
             , mndy(0.0)
             , mnOrientation(0.0)
+            , mnX(0)
+            , mnY(0)
             , mnLocalColorPrecision(0)
+            , mnCompressionMode(0)
             { };
         ~CGMBitmapDescriptor()
         {
commit 1654b7f31d2ff555543348f57c784ac0cef7e3e4
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Thu Feb 6 13:06:27 2014 +0000

    coverity#707804 Uninitialized scalar field
    
    Change-Id: Ic949e85493f349d9ce36af5333a2cfbd63aad79a

diff --git a/filter/source/graphicfilter/icgm/bundles.hxx b/filter/source/graphicfilter/icgm/bundles.hxx
index fee4b2c..250c6be 100644
--- a/filter/source/graphicfilter/icgm/bundles.hxx
+++ b/filter/source/graphicfilter/icgm/bundles.hxx
@@ -88,10 +88,12 @@ public:
     EdgeType            eEdgeType;
     double              nEdgeWidth;
 
-                        EdgeBundle() {};
-    virtual Bundle*     Clone() { return new EdgeBundle( *this ); } ;
-            EdgeBundle& operator=( EdgeBundle& rEdgeBundle );
-    virtual             ~EdgeBundle() {};
+    EdgeBundle()
+        : eEdgeType(ET_NONE)
+        , nEdgeWidth(0)
+    {}
+    virtual Bundle*     Clone() { return new EdgeBundle( *this ); }
+    EdgeBundle& operator=( EdgeBundle& rEdgeBundle );
 };
 
 // ---------------------------------------------------------------
@@ -121,13 +123,13 @@ public:
     long                nFillPatternIndex;
     long                nFillHatchIndex;
 
-    FillBundle(FIS_HOLLOW)
-        : eFillInteriorStyle()
+    FillBundle()
+        : eFillInteriorStyle(FIS_HOLLOW)
         , nFillPatternIndex(0)
         , nFillHatchIndex(0)
     {}
     virtual Bundle*     Clone() { return new FillBundle( *this ); }
-    FillBundle& operator=( FillBundle& rFillBundle )
+    FillBundle& operator=( FillBundle& rFillBundle );
 };
 
 
commit 25a893d1715e721d08df7818d642a9197d436796
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Thu Feb 6 13:05:42 2014 +0000

    coverity#707805 Uninitialized scalar field
    
    Change-Id: Ie08f92fbdca3048a7ac0721f058300ee364f1998

diff --git a/filter/source/graphicfilter/icgm/bundles.hxx b/filter/source/graphicfilter/icgm/bundles.hxx
index e6fe4a0..fee4b2c 100644
--- a/filter/source/graphicfilter/icgm/bundles.hxx
+++ b/filter/source/graphicfilter/icgm/bundles.hxx
@@ -121,10 +121,13 @@ public:
     long                nFillPatternIndex;
     long                nFillHatchIndex;
 
-                        FillBundle() {};
-    virtual Bundle*     Clone() { return new FillBundle( *this ); } ;
-            FillBundle& operator=( FillBundle& rFillBundle );
-    virtual             ~FillBundle() {};
+    FillBundle(FIS_HOLLOW)
+        : eFillInteriorStyle()
+        , nFillPatternIndex(0)
+        , nFillHatchIndex(0)
+    {}
+    virtual Bundle*     Clone() { return new FillBundle( *this ); }
+    FillBundle& operator=( FillBundle& rFillBundle )
 };
 
 
commit 7ac848c90546252d8fc1064511aa6337eaff0daa
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Thu Feb 6 12:14:12 2014 +0000

    coverity#707806 Uninitialized scalar field
    
    Change-Id: I20b5bd30e9bc4e881e2d9b5176f6f1cc6c1aabbd

diff --git a/filter/source/graphicfilter/icgm/bundles.hxx b/filter/source/graphicfilter/icgm/bundles.hxx
index 81a1f63..e6fe4a0 100644
--- a/filter/source/graphicfilter/icgm/bundles.hxx
+++ b/filter/source/graphicfilter/icgm/bundles.hxx
@@ -55,10 +55,13 @@ public:
     LineType            eLineType;
     double              nLineWidth;
 
-                        LineBundle() {};
-    virtual Bundle*     Clone() { return new LineBundle( *this ); };
-            LineBundle& operator=( LineBundle& rLineBundle );
-    virtual             ~LineBundle() {};
+    LineBundle()
+        : eLineType(LT_SOLID)
+        , nLineWidth(0)
+    {}
+
+    virtual Bundle* Clone() { return new LineBundle( *this ); }
+    LineBundle& operator=( LineBundle& rLineBundle );
 };
 
 // ---------------------------------------------------------------
commit 9c1b4e044a152bf53b86fff16a2f2e7c8b8f93aa
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Thu Feb 6 12:09:14 2014 +0000

    coverity#1038484 Uncaught exception
    
    Change-Id: I0067dfd9b020dc02d6611e37ac49d585b46ec42d

diff --git a/sd/source/ui/framework/configuration/ConfigurationController.cxx b/sd/source/ui/framework/configuration/ConfigurationController.cxx
index 1286c5a..6d1f708 100644
--- a/sd/source/ui/framework/configuration/ConfigurationController.cxx
+++ b/sd/source/ui/framework/configuration/ConfigurationController.cxx
@@ -252,14 +252,10 @@ void SAL_CALL ConfigurationController::notifyEvent (
     mpImplementation->mpBroadcaster->NotifyListeners(rEvent);
 }
 
-
-
-
-
 //----- XConfigurationController ----------------------------------------------
 
-void SAL_CALL ConfigurationController::lock (void)
-    throw (RuntimeException)
+void SAL_CALL ConfigurationController::lock()
+    throw (RuntimeException, std::exception)
 {
     OSL_ASSERT(mpImplementation.get()!=NULL);
     OSL_ASSERT(mpImplementation->mpConfigurationUpdater.get()!=NULL);
diff --git a/sd/source/ui/inc/framework/ConfigurationController.hxx b/sd/source/ui/inc/framework/ConfigurationController.hxx
index af5e482..3341246 100644
--- a/sd/source/ui/inc/framework/ConfigurationController.hxx
+++ b/sd/source/ui/inc/framework/ConfigurationController.hxx
@@ -86,8 +86,9 @@ public:
 
     // XConfigurationController
 
-    virtual void SAL_CALL lock (void)
-        throw (css::uno::RuntimeException);
+    virtual void SAL_CALL lock()
+        throw (css::uno::RuntimeException,
+               std::exception);
 
     virtual void SAL_CALL unlock (void)
         throw (css::uno::RuntimeException);
commit e30c412185619002fdce3662ea18d48e4eb3c3bb
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Thu Feb 6 12:08:07 2014 +0000

    coverity#1038483 Uncaught exception
    
    Change-Id: I126c4df9ed57674f5eba7a205fa82fdd5ac0a5cc

diff --git a/sd/source/ui/framework/configuration/ConfigurationController.cxx b/sd/source/ui/framework/configuration/ConfigurationController.cxx
index 7e02035..1286c5a 100644
--- a/sd/source/ui/framework/configuration/ConfigurationController.cxx
+++ b/sd/source/ui/framework/configuration/ConfigurationController.cxx
@@ -500,7 +500,7 @@ Reference<XConfiguration> SAL_CALL ConfigurationController::getCurrentConfigurat
 */
 void SAL_CALL ConfigurationController::restoreConfiguration (
     const Reference<XConfiguration>& rxNewConfiguration)
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     ::osl::MutexGuard aGuard (maMutex);
     ThrowIfDisposed();
diff --git a/sd/source/ui/inc/framework/ConfigurationController.hxx b/sd/source/ui/inc/framework/ConfigurationController.hxx
index 592cdd8..af5e482 100644
--- a/sd/source/ui/inc/framework/ConfigurationController.hxx
+++ b/sd/source/ui/inc/framework/ConfigurationController.hxx
@@ -123,7 +123,8 @@ public:
     virtual void SAL_CALL restoreConfiguration (
         const css::uno::Reference<css::drawing::framework::XConfiguration>&
         rxConfiguration)
-        throw (css::uno::RuntimeException);
+        throw (css::uno::RuntimeException,
+               std::exception);
 
 
     // XConfigurationControllerBroadcaster
commit 552c82427cab08181f7ed164a6b2d6d148a09a8a
Author: Caolán McNamara <caolanm at redhat.com>
Date:   Thu Feb 6 12:06:31 2014 +0000

    coverity#1038477 Uncaught exception
    
    Change-Id: I12ec3781f60f56798423082e2a8dd243a68e6c65

diff --git a/sc/source/ui/vba/vbanames.cxx b/sc/source/ui/vba/vbanames.cxx
index d274fb0..acc5ec0 100644
--- a/sc/source/ui/vba/vbanames.cxx
+++ b/sc/source/ui/vba/vbanames.cxx
@@ -96,7 +96,8 @@ ScVbaNames::Add( const css::uno::Any& Name ,
                                         const css::uno::Any& /*RefersToLocal*/,
                                         const css::uno::Any& /*CategoryLocal*/,
                                         const css::uno::Any& RefersToR1C1,
-                                        const css::uno::Any& RefersToR1C1Local ) throw (css::uno::RuntimeException)
+                                        const css::uno::Any& RefersToR1C1Local )
+    throw (css::uno::RuntimeException, std::exception)
 {
     OUString sName;
     uno::Reference< excel::XRange > xRange;
diff --git a/sc/source/ui/vba/vbanames.hxx b/sc/source/ui/vba/vbanames.hxx
index 8ee9416..5a7d906 100644
--- a/sc/source/ui/vba/vbanames.hxx
+++ b/sc/source/ui/vba/vbanames.hxx
@@ -61,7 +61,9 @@ public:
                     const css::uno::Any& aRefersToLocal,
                     const css::uno::Any& aCategoryLocal,
                     const css::uno::Any& aRefersToR1C1,
-                    const css::uno::Any& aRefersToR1C1Local ) throw (css::uno::RuntimeException);
+                    const css::uno::Any& aRefersToR1C1Local )
+        throw (css::uno::RuntimeException,
+               std::exception);
 
     virtual css::uno::Any createCollectionObject( const css::uno::Any& aSource );
 


More information about the Libreoffice-commits mailing list
diff --git a/include/vcl/settings.hxx b/include/vcl/settings.hxx
index ed9e617..d9711de 100644
--- a/include/vcl/settings.hxx
+++ b/include/vcl/settings.hxx
@@ -1144,7 +1144,8 @@ public:
     const LanguageTag&                      GetLanguageTag() const;
     void                                    SetUILanguageTag( const LanguageTag& rLanguageTag );
     const LanguageTag&                      GetUILanguageTag() const;
-    bool                                    GetLayoutRTL() const;   // returns true if UI language requires right-to-left UI
+    bool                                    GetLayoutRTL() const;   // returns true if UI language requires right-to-left Text Layout
+    bool                                    GetMathLayoutRTL() const;   // returns true if UI language requires right-to-left Math Layout
     const LocaleDataWrapper&                GetLocaleDataWrapper() const;
     const LocaleDataWrapper&                GetUILocaleDataWrapper() const;
     const vcl::I18nHelper&                  GetLocaleI18nHelper() const;